==> cnr-data-information-oai-publisher-1.1.2-20140224.114655-27-sources.jar: eu/dnetlib/data/information/oai/publisher/store/RecordInfoGenerator.java <==
package eu.dnetlib.data.information.oai.publisher.store;

import java.io.StringReader;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang.StringEscapeUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.io.SAXReader;

import com.google.common.collect.Sets;
import com.mongodb.DBObject;

import eu.dnetlib.data.information.oai.publisher.OaiPublisherRuntimeException;
import eu.dnetlib.data.information.oai.publisher.conf.OAIConfigurationReader;
import eu.dnetlib.data.information.oai.publisher.core.MetadataExtractor;
import eu.dnetlib.data.information.oai.publisher.info.RecordInfo;

/**
 * Helper class to generate a RecordInfo object from a Mongo DBObject.
 * 
 * @author alessia
 * 
 */
public class RecordInfoGenerator {

	@Resource
	private MetadataExtractor metadataExtractor;

	@SuppressWarnings("unchecked")
	public RecordInfo transformDBObject(final DBObject object, final boolean includeBody) {
		String id = (String) object.get(OAIConfigurationReader.ID_FIELD);
		// need to escape the identifier, otherwise the XML breaks
		id = StringEscapeUtils.escapeXml(id);
		boolean deleted = (Boolean) object.get("deleted");
		RecordInfo record = new RecordInfo();
		record.setIdentifier(id);
		record.setInternalId(object.get("_id").toString());
		record.setDatestamp((Date) object.get(OAIConfigurationReader.DATESTAMP_FIELD));
		record.setDeleted(deleted);
		List<String> sets = (List<String>) object.get(OAIConfigurationReader.SET_FIELD);
		if (sets != null) {
			record.setSetspecs(Sets.newHashSet(sets));
		}
		if (includeBody && !deleted) {
			String body = (String) object.get(OAIConfigurationReader.BODY_FIELD);
			final SAXReader reader = new SAXReader();
			Document doc;
			try {
				doc = reader.read(new StringReader(body));
				record.setMetadata(this.metadataExtractor.evaluate(doc));

			} catch (DocumentException e) {
				throw new OaiPublisherRuntimeException(e);
			}
		}
		return record;

	}

	public MetadataExtractor getMetadataExtractor() {
		return metadataExtractor;
	}

	public void setMetadataExtractor(final MetadataExtractor metadataExtractor) {
		this.metadataExtractor = metadataExtractor;
	}

}

==> cnr-data-information-oai-publisher-1.1-20131104.112735-20-sources.jar: eu/dnetlib/data/information/oai/publisher/store/RecordInfoGenerator.java <==
package eu.dnetlib.data.information.oai.publisher.store;

import java.io.StringReader;
import java.util.Collection;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import org.apache.commons.lang.StringEscapeUtils;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.io.SAXReader;

import com.google.common.base.Function;
import com.google.common.collect.Collections2;
import com.google.common.collect.Lists;
import com.mongodb.DBObject;

import eu.dnetlib.data.information.oai.publisher.OaiPublisherRuntimeException;
import eu.dnetlib.data.information.oai.publisher.conf.PublisherConfigurationReader;
import eu.dnetlib.data.information.oai.publisher.core.DNetOAICore;
import eu.dnetlib.data.information.oai.publisher.core.MetadataExtractor;
import eu.dnetlib.data.information.oai.publisher.info.RecordInfo;

/**
 * Helper class to generate a RecordInfo object from a Mongo DBObject.
 * 
 * @author alessia
 * 
 */
public class RecordInfoGenerator {

	@Resource
	private MetadataExtractor metadataExtractor;

	@SuppressWarnings("unchecked")
	public RecordInfo transformDBObject(final DBObject object, final boolean includeBody) {
		String id = (String) object.get(PublisherConfigurationReader.ID_FIELD);
		// need to escape the identifier, otherwise the XML breaks
		id = StringEscapeUtils.escapeXml(id);
		boolean deleted = (Boolean) object.get("deleted");
		RecordInfo record = new RecordInfo();
		record.setIdentifier(id);
		record.setInternalId(object.get("_id").toString());
		record.setDatestamp((Date) object.get(PublisherConfigurationReader.DATESTAMP_FIELD));
		record.setDeleted(deleted);
		List<String> sets = (List<String>) object.get(PublisherConfigurationReader.SET_FIELD);
		Collection<String> setsNoSuffix = Collections2.transform(sets, new Function<String, String>() {

			@Override
			public String apply(final String str) {
				return str.replace("_" + DNetOAICore.REPO_BASE64_SUFFIX, "");
			}

		});
		record.setSetspecs(Lists.newArrayList(setsNoSuffix));
		if (includeBody && !deleted) {
			String body = (String) object.get(PublisherConfigurationReader.BODY_FIELD);
			final SAXReader reader = new SAXReader();
			Document doc;
			try {
				doc = reader.read(new StringReader(body));
				record.setMetadata(this.metadataExtractor.evaluate(doc));

			} catch (DocumentException e) {
				throw new OaiPublisherRuntimeException(e);
			}
		}
		return record;

	}

	public MetadataExtractor getMetadataExtractor() {
		return metadataExtractor;
	}

	public void setMetadataExtractor(final MetadataExtractor metadataExtractor) {
		this.metadataExtractor = metadataExtractor;
	}
}
